from django.apps import AppConfig


class WagtailFrontendCacheAppConfig(AppConfig):
    name = 'wagtail.contrib.wagtailfrontendcache'
    label = 'wagtailfrontendcache'
    verbose_name = "Wagtail frontend cache"
