{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% blocktrans %}New  {{ snippet_type_name}}{% endblocktrans %}{% endblock %}
{% block bodyclass %}menu-snippets{% endblock %}
{% block content %}
    {% trans "New" as new_str %}
    {% include "wagtailadmin/shared/header.html" with title=new_str subtitle=snippet_type_name icon="snippet" %}

    <form action="{% url 'wagtailsnippets_create' content_type.app_label content_type.model %}" method="POST">
        {% csrf_token %}
        {{ edit_handler.render_form_content }}
        
        <footer>
            <ul>
                <li class="actions">
                    <div class="dropdown dropup match-width">
                        <div><input type="submit" value="{% trans 'Save' %}" /></div>
                    </div>
                </li>
            </ul>
        </footer>
    </form>
   
{% endblock %}

{% block extra_css %}
    {% include "wagtailadmin/pages/_editor_css.html" %}
{% endblock %}
{% block extra_js %}
    {% include "wagtailadmin/pages/_editor_js.html" %}
{% endblock %}
