{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Add redirect" %}{% endblock %}
{% block bodyclass %}menu-redirects{% endblock %}
{% block content %}
    {% trans "Add redirect" as add_red_str %}
    {% include "wagtailadmin/shared/header.html" with title=add_red_str icon="redirect" %}

    <form action="{% url 'wagtailredirects_add_redirect' %}" method="POST" class="nice-padding">
        {% csrf_token %}
        {{ edit_handler.render_form_content }}

        <div>
            <input type="submit" value="{% trans 'Save' %}" />
        </div>
    </form>
    
{% endblock %}

{% block extra_js %}
    {% include "wagtailadmin/pages/_editor_js.html" %}
{% endblock %}