{% load i18n %}
<form class="search-bar full-width nice-padding" action="{% url 'wagtailadmin_choose_page' %}?{{ querystring }}" method="get">
    <ul class="fields">
        {% for field in search_form %}
            {% include "wagtailadmin/shared/field_as_li.html" with field=field %}
        {% endfor %}
        <li class="submit"><input type="submit" value="{% trans 'Search' %}" /></li>
    </ul>
</form>
