{% extends "wagtailadmin/edit_handlers/chooser_panel.html" %}

{% block chosen_state_view %}
    <span class="title">{{ page.title }}</span>
{% endblock %}

{% block choose_another_button_label %}{{ choose_another_text_str }}{% endblock %}
{% block choose_button_label %}{{ choose_one_text_str }}{% endblock %}
