{% load gravatar wagtailadmin_tags %}
{% load i18n %}
<nav class="nav-main">
    <ul>
        {{ menu_html }}

        <li class="footer">
            <div class="avatar icon icon-user"><a href="{% url 'wagtailadmin_account' %}" title="{% trans 'Account settings' %}">{% if request.user.email %}<img src="{% gravatar_url request.user.email %}" />{% endif %}</a></div>
            <a href="{% url 'wagtailadmin_logout' %}">{% trans "Log out" %}</a>
        </li>
    </ul>
</nav>
