{% load i18n %}
{% if queries %}
    {% if is_searching %}
        <h2>
        {% blocktrans count counter=queries|length %}
            There is one match
        {% plural %}
            There are {{ counter }} matches
        {% endblocktrans %}
        </h2>
    {% endif %}

    {% include "wagtailsearch/editorspicks/list.html" %}

    {% include "wagtailadmin/shared/pagination_nav.html" with items=queries is_searching=is_searching linkurl="wagtailsearch_editorspicks_index" %}
{% else %}
    {% if is_searching %}
         <p>{% blocktrans %}Sorry, no promoted results match "<em>{{ query_string }}</em>"{% endblocktrans %}</p>
    {% else %}
        {% url 'wagtailsearch_editorspicks_add' as wagtailsearch_editorspicks_add_url %}
        <p>{% blocktrans %}No promoted results have been created. Why not <a href="{{ wagtailsearch_editorspicks_add_url }}">add one</a>?{% endblocktrans %}</p>
    {% endif %}
{% endif %}
