<!DOCTYPE HTML>
<html>
    <head>
        <title>{{ self.title }}</title>
    </head>
    <body>
        <h1>{{ self.title }}</h1>
        {% include "tests/includes/event_listing.html" %}
    </body>
</html>
