{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Delete site" %}{% endblock %}
{% block bodyclass %}menu-site{% endblock %}

{% block content %}
    {% trans "Delete site" as del_str %}
    {% include "wagtailadmin/shared/header.html" with title=del_str subtitle=site.hostname icon="site" %}

    <div class="row row-flush nice-padding">
        <p>{% trans "Are you sure you want to delete this site?" %}</p>
        <form action="{% url 'wagtailsites_delete' site.id %}" method="POST">
            {% csrf_token %}
            <input type="submit" value="{% trans 'Yes, delete' %}" class="serious" />
        </form>
    </div>
{% endblock %}
