{% load i18n %}
{% trans "Choose a page" as choose_str %}
{% include "wagtailadmin/shared/header.html" with title=choose_str %}

<div class="nice-padding">
    {% include 'wagtailadmin/chooser/_link_types.html' with current='internal' %}

    {% include 'wagtailadmin/chooser/_search_form.html' %}

    <div class="page-results">{# content in here will be replaced by live search results #}
        {% include 'wagtailadmin/chooser/_search_results.html' %}
    </div>
</div>
