{% load wagtailcore_tags %}

<!DOCTYPE HTML>
<html>
    <head>
        <title>Event: {{ self.title }}</title>
    </head>
    <body>
        <h1>{{ self.title }}</h1>
        <h2>Event</h2>
        <p><a href="{% slugurl 'events' %}">Back to events index</a></p>
    </body>
</html>
