@import "../variables.scss";
@import "../mixins.scss";
@import "../grid.scss";

h1{
    font-weight:300;
    font-size:2.2em;
}
header{
    .col1{
        width:50px;
        margin-right:1em;
        padding:0;
    }
    h1,h2{
        color:white;
    }
    h2{
        text-transform:none;
    }
}

.panel{
    margin-bottom:4em;
}

.summary{
    @include clearfix();
    background-color:$color-grey-5;
    margin-bottom:2em;
    padding-top:2em;
    padding-bottom:2em;

    ul.stats{
        @include clearfix();
        @include unlist();
        width:100%;

        li{
            @include column(4);

            &:before{
                opacity:0.2;
                font-size:6em;
                float:left;
            }
        }

        a{
            position:relative;
            display:block;
            width:100%;
            height:100%;
        }

        span{
            font-family:Bitter, Georgia, serif;
            display:block;
            font-size:4em;
            line-height:1em;
            font-weight:300;
        }
    }

    .search-bar{
        @include clearfix();
        border-top:1px solid $color-grey-4;
        padding:1em 0 0 0;

        h2{
            display:inline-block;
            margin-right:1em;
        }
        .fields{
            display:inline-block;
            clear:none;
        }
        .field{
            display:inline-block;
        }

        label{
            display:inline-blo;
        }
        input{
            background-color:white;
        }
    }

}
