{% load i18n %}
{% trans "Choose" as choose_str %}
{% include "wagtailadmin/shared/header.html" with title=choose_str subtitle=snippet_type_name icon="snippet" %}

<div class="nice-padding">
    {% include "wagtailsnippets/snippets/list.html" with choosing=1 %}
</div>
