{% extends "wagtailadmin/edit_handlers/chooser_panel.html" %}
{% load i18n %}

{% block chooser_class %}snippet-chooser{% endblock %}

{% block chosen_state_view %}
    <span class="title">{% if is_chosen %}{{ item }}{% endif %}</span>
{% endblock %}

{% block choose_another_button_label %}{% blocktrans %}Choose another {{ snippet_type_name }}{% endblocktrans %}{% endblock %}
{% block choose_button_label %}{% blocktrans %}Choose {{ snippet_type_name }}{% endblocktrans %}{% endblock %}
