{% extends "wagtailadmin/shared/field_as_li.html" %}
{% load i18n %}
{% block form_field %}
    <span class="icon icon-image">{{ image.filename }}</span><br /><br />

    {% trans "Change image:" %}
    {{ field }}
{% endblock %}
