h1,h2,h3,h4,h5,h6{
    font-weight:normal;
}

h1{
    line-height:1.3em;
    font-size:1.5em;
    text-transform:uppercase;
    color:$color-grey-1;
    font-weight:600;

    span{
        text-transform:none;
        font-weight:300;
    }

    .homepage &{
        text-transform:none;
    }
}
h2{
    text-transform:uppercase;
    font-size:1.3em;
    font-family:Open Sans;
    font-weight:600;
    color:$color-grey-2;

    .page-explorer &{
        text-transform:none;
    }
}
p{
    margin-top:0;
}

a{
    @include transition(color 0.2s ease, background-color 0.2s ease);
    outline:none;
    color:$color-link;
    text-decoration:none;

    &:hover{
        color:$color-link-hover;
    }
}

code{
    @include box-shadow(inset 0px 0px 4px 0px rgba(0, 0, 0, 0.2));
    background-color:$color-fieldset-hover;
    padding:2px 5px;
}

kbd{
    @include border-radius(3px);
    font-family:Open Sans, Arial, sans-serif;
    border:1px solid $color-grey-2;
    border-color:rgba(0,0,0,0.2);
    padding:0.3em 0.5em;
}

/* Help text formatters */

.help-block{
    padding:1em;
    margin:1em 0;
    clear:both;

    p{
        margin-top:0;

        &:last-child{
            margin-bottom:0;
        }
    }
}
    .help-info, .help-warning, .help-critical{
        @include border-radius(3px);
        padding-left:3.5em;
        position:relative;

        &:before{
            font-family:wagtail;
            position:absolute;
            left:1em;
            top:0.7em;
            content:"?";
            font-size:1.4em;
        }
    }
    .help-info{
        background-color:lighten($color-blue, 30%);

        &:before{
            color:$color-blue;
        }
    }

    .help-warning{
        background-color:lighten($color-orange, 30%);

        &:before{
            color:$color-orange;
            content:"!";
        }
    }

    .help-critical{
        background-color:lighten($color-red, 40%);

        &:before{
            color:$color-red;
            content:"!";
        }
    }

